Class: Aws::NetworkMonitor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkMonitor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkmonitor/client.rb,
sig/client.rbs
Overview
An API client for NetworkMonitor. To construct a client, you need to configure a :region and :credentials.
client = Aws::NetworkMonitor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateMonitorResponseSuccess, _CreateProbeResponseSuccess, _DeleteMonitorResponseSuccess, _DeleteProbeResponseSuccess, _GetMonitorResponseSuccess, _GetProbeResponseSuccess, _ListMonitorsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateMonitorResponseSuccess, _UpdateProbeResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_monitor(params = {}) ⇒ Types::CreateMonitorOutput
Creates a monitor between a source subnet and destination IP address.
-
#create_probe(params = {}) ⇒ Types::CreateProbeOutput
Create a probe within a monitor.
-
#delete_monitor(params = {}) ⇒ Struct
Deletes a specified monitor.
-
#delete_probe(params = {}) ⇒ Struct
Deletes the specified probe.
-
#get_monitor(params = {}) ⇒ Types::GetMonitorOutput
Returns details about a specific monitor.
-
#get_probe(params = {}) ⇒ Types::GetProbeOutput
Returns the details about a probe.
-
#list_monitors(params = {}) ⇒ Types::ListMonitorsOutput
Returns a list of all of your monitors.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags assigned to this resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds key-value pairs to a monitor or probe.
-
#untag_resource(params = {}) ⇒ Struct
Removes a key-value pair from a monitor or probe.
-
#update_monitor(params = {}) ⇒ Types::UpdateMonitorOutput
Updates the
aggregationPeriodfor a monitor. -
#update_probe(params = {}) ⇒ Types::UpdateProbeOutput
Updates a monitor probe.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-networkmonitor/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1147 1148 1149 |
# File 'lib/aws-sdk-networkmonitor/client.rb', line 1147 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1150 1151 1152 |
# File 'lib/aws-sdk-networkmonitor/client.rb', line 1150 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 |
# File 'lib/aws-sdk-networkmonitor/client.rb', line 1120 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NetworkMonitor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-networkmonitor' context[:gem_version] = '1.38.0' Seahorse::Client::Request.new(handlers, context) end |
#create_monitor(params = {}) ⇒ Types::CreateMonitorOutput
Creates a monitor between a source subnet and destination IP address. Within a monitor you'll create one or more probes that monitor network traffic between your source Amazon Web Services VPC subnets and your destination IP addresses. Each probe then aggregates and sends metrics to Amazon CloudWatch.
You can also create a monitor with probes using this command. For each probe, you define the following:
-
source—The subnet IDs where the probes will be created. -
destination— The target destination IP address for the probe. -
destinationPort—Required only if the protocol isTCP. -
protocol—The communication protocol between the source and destination. This will be eitherTCPorICMP. -
packetSize—The size of the packets. This must be a number between56and8500. -
(Optional)
tags—Key-value pairs created and assigned to the probe.
90 |
# File 'sig/client.rbs', line 90
def create_monitor: (
|
#create_probe(params = {}) ⇒ Types::CreateProbeOutput
Create a probe within a monitor. Once you create a probe, and it
begins monitoring your network traffic, you'll incur billing charges
for that probe. This action requires the monitorName parameter. Run
ListMonitors to get a list of monitor names. Note the name of the
monitorName you want to create the probe for.
125 |
# File 'sig/client.rbs', line 125
def create_probe: (
|
#delete_monitor(params = {}) ⇒ Struct
Deletes a specified monitor.
This action requires the monitorName parameter. Run ListMonitors
to get a list of monitor names.
144 |
# File 'sig/client.rbs', line 144
def delete_monitor: (
|
#delete_probe(params = {}) ⇒ Struct
Deletes the specified probe. Once a probe is deleted you'll no longer incur any billing fees for that probe.
This action requires both the monitorName and probeId parameters.
Run ListMonitors to get a list of monitor names. Run GetMonitor to
get a list of probes and probe IDs. You can only delete a single probe
at a time using this action.
153 |
# File 'sig/client.rbs', line 153
def delete_probe: (
|
#get_monitor(params = {}) ⇒ Types::GetMonitorOutput
Returns details about a specific monitor.
This action requires the monitorName parameter. Run ListMonitors
to get a list of monitor names.
171 |
# File 'sig/client.rbs', line 171
def get_monitor: (
|
#get_probe(params = {}) ⇒ Types::GetProbeOutput
Returns the details about a probe. This action requires both the
monitorName and probeId parameters. Run ListMonitors to get a
list of monitor names. Run GetMonitor to get a list of probes and
probe IDs.
193 |
# File 'sig/client.rbs', line 193
def get_probe: (
|
#list_monitors(params = {}) ⇒ Types::ListMonitorsOutput
Returns a list of all of your monitors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
205 |
# File 'sig/client.rbs', line 205
def list_monitors: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags assigned to this resource.
217 |
# File 'sig/client.rbs', line 217
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds key-value pairs to a monitor or probe.
226 |
# File 'sig/client.rbs', line 226
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a key-value pair from a monitor or probe.
236 |
# File 'sig/client.rbs', line 236
def untag_resource: (
|
#update_monitor(params = {}) ⇒ Types::UpdateMonitorOutput
Updates the aggregationPeriod for a monitor. Monitors support an
aggregationPeriod of either 30 or 60 seconds. This action
requires the monitorName and probeId parameter. Run ListMonitors
to get a list of monitor names.
251 |
# File 'sig/client.rbs', line 251
def update_monitor: (
|
#update_probe(params = {}) ⇒ Types::UpdateProbeOutput
Updates a monitor probe. This action requires both the monitorName
and probeId parameters. Run ListMonitors to get a list of monitor
names. Run GetMonitor to get a list of probes and probe IDs.
You can update the following para create a monitor with probes using this command. For each probe, you define the following:
-
state—The state of the probe. -
destination— The target destination IP address for the probe. -
destinationPort—Required only if the protocol isTCP. -
protocol—The communication protocol between the source and destination. This will be eitherTCPorICMP. -
packetSize—The size of the packets. This must be a number between56and8500. -
(Optional)
tags—Key-value pairs created and assigned to the probe.
274 |
# File 'sig/client.rbs', line 274
def update_probe: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1140 1141 1142 |
# File 'lib/aws-sdk-networkmonitor/client.rb', line 1140 def waiter_names [] end |