Class: Aws::NetworkMonitor::Types::CreateMonitorInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkmonitor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_periodInteger

The time, in seconds, that metrics are aggregated and sent to Amazon CloudWatch. Valid values are either 30 or 60. 60 is the default if no period is chosen.

Returns:

  • (Integer)


69
70
71
72
73
74
75
76
77
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69

class CreateMonitorInput < Struct.new(
  :monitor_name,
  :probes,
  :aggregation_period,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69

class CreateMonitorInput < Struct.new(
  :monitor_name,
  :probes,
  :aggregation_period,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_nameString

The name identifying the monitor. It can contain only letters, underscores (_), or dashes (-), and can be up to 200 characters.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69

class CreateMonitorInput < Struct.new(
  :monitor_name,
  :probes,
  :aggregation_period,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#probesArray<Types::CreateMonitorProbeInput>

Displays a list of all of the probes created for a monitor.

Returns:



69
70
71
72
73
74
75
76
77
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69

class CreateMonitorInput < Struct.new(
  :monitor_name,
  :probes,
  :aggregation_period,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of key-value pairs created and assigned to the monitor.

Returns:

  • (Hash<String,String>)


69
70
71
72
73
74
75
76
77
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69

class CreateMonitorInput < Struct.new(
  :monitor_name,
  :probes,
  :aggregation_period,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end