Class: Aws::NetworkMonitor::Types::CreateMonitorInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkMonitor::Types::CreateMonitorInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_period ⇒ Integer
The time, in seconds, that metrics are aggregated and sent to Amazon CloudWatch.
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request.
-
#monitor_name ⇒ String
The name identifying the monitor.
-
#probes ⇒ Array<Types::CreateMonitorProbeInput>
Displays a list of all of the probes created for a monitor.
-
#tags ⇒ Hash<String,String>
The list of key-value pairs created and assigned to the monitor.
Instance Attribute Details
#aggregation_period ⇒ Integer
The time, in seconds, that metrics are aggregated and sent to Amazon CloudWatch. Valid values are either 30 or 60. 60 is the default if no period is chosen.
69 70 71 72 73 74 75 76 77 |
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69 class CreateMonitorInput < Struct.new( :monitor_name, :probes, :aggregation_period, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
69 70 71 72 73 74 75 76 77 |
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69 class CreateMonitorInput < Struct.new( :monitor_name, :probes, :aggregation_period, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_name ⇒ String
The name identifying the monitor. It can contain only letters, underscores (_), or dashes (-), and can be up to 200 characters.
69 70 71 72 73 74 75 76 77 |
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69 class CreateMonitorInput < Struct.new( :monitor_name, :probes, :aggregation_period, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#probes ⇒ Array<Types::CreateMonitorProbeInput>
Displays a list of all of the probes created for a monitor.
69 70 71 72 73 74 75 76 77 |
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69 class CreateMonitorInput < Struct.new( :monitor_name, :probes, :aggregation_period, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of key-value pairs created and assigned to the monitor.
69 70 71 72 73 74 75 76 77 |
# File 'lib/aws-sdk-networkmonitor/types.rb', line 69 class CreateMonitorInput < Struct.new( :monitor_name, :probes, :aggregation_period, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |